@@ -1,5 +1,26 @@
 ## MIF algorithm functions
 
+## define the mif class
+setClass(
+         'mif',
+         contains='pfilterd.pomp',
+         slots=c(
+           transform = "logical",
+           ivps = 'character',
+           pars = 'character',
+           Nmif = 'integer',
+           particles = 'function',
+           var.factor='numeric',
+           ic.lag='integer',
+           cooling.type='character',
+           cooling.fraction='numeric',
+           method='character',
+           random.walk.sd = 'numeric',
+           conv.rec = 'matrix'
+           )
+         )
+
+
 default.pomp.particles.fun <- function (Np, center, sd, ...) {
   matrix(
          data=rnorm(
