@@ -104,31 +104,30 @@ dat <- '"time";"X";"Y"
 100;1,28071364632546;1,23495259845453
 '
 
-po <- pomp(
-           data=subset(read.csv2(text=dat),select=-X),
-           times="time",
-           t0=0,
-           params=c(K=1,r=0.1,sigma=0.1,tau=0.1,X.0=1),
-           rprocess=discrete.time.sim(
-             step.fun="_gompertz_simulator"
-             ),
-           rmeasure="_gompertz_normal_rmeasure",
-           dmeasure="_gompertz_normal_dmeasure",
-           skeleton.type="map",
-           skeleton="_gompertz_skeleton",
-           paramnames=c("r","K","sigma","tau"),
-           statenames=c("X"),
-           obsnames=c("Y"),
-           parameter.transform=function(params,...){
-             exp(params)
-           },
-           parameter.inv.transform=function(params,...){
-             log(params)
-           }
-           )
+pomp(
+     data=subset(read.csv2(text=dat),select=-X),
+     times="time",
+     t0=0,
+     params=c(K=1,r=0.1,sigma=0.1,tau=0.1,X.0=1),
+     rprocess=discrete.time.sim(
+       step.fun="_gompertz_simulator"
+       ),
+     rmeasure="_gompertz_normal_rmeasure",
+     dmeasure="_gompertz_normal_dmeasure",
+     skeleton.type="map",
+     skeleton="_gompertz_skeleton",
+     paramnames=c("r","K","sigma","tau"),
+     statenames=c("X"),
+     obsnames=c("Y"),
+     parameter.transform=function(params,...){
+       exp(params)
+     },
+     parameter.inv.transform=function(params,...){
+       log(params)
+     }
+     ) -> gompertz
 
 ## the following was used to create the data included
 ## simulate(po,nsim=1,seed=299438676L) -> gompertz
 
-assign("gompertz",po,envir=.GlobalEnv)
 c("gompertz")
