@@ -35,16 +35,10 @@ SEXP do_init_state (SEXP object, SEXP params, SEXP t0)
 
   // begin to construct the call
   PROTECT(fcall = VectorToPairList(GET_SLOT(object,install("userdata")))); nprotect++;
-  PROTECT(fcall = LCONS(GET_SLOT(object,install("covarnames")),fcall)); nprotect++;
-  SET_TAG(fcall,install("covarnames"));
-  PROTECT(fcall = LCONS(GET_SLOT(object,install("paramnames")),fcall)); nprotect++;
-  SET_TAG(fcall,install("paramnames"));
-  PROTECT(fcall = LCONS(GET_SLOT(object,install("statenames")),fcall)); nprotect++;
-  SET_TAG(fcall,install("statenames"));
 
   // extract covariates and interpolate
   PROTECT(tcovar = GET_SLOT(object,install("tcovar"))); nprotect++;
-  if (LENGTH(tcovar) > 0) {	// do table lookkup
+  if (LENGTH(tcovar) > 0) {	// do table lookup
     PROTECT(covar = GET_SLOT(object,install("covar"))); nprotect++;
     PROTECT(covars = lookup_in_table(tcovar,covar,t0)); nprotect++;
     PROTECT(fcall = LCONS(covars,fcall)); nprotect++;
